@@ -16,7 +16,7 @@
 Top-level package for Q-CTRL Open Controls.
 """
 
-__version__ = "8.0.0"
+__version__ = "8.1.0"
 
 from .driven_controls.driven_control import DrivenControl
 from .driven_controls.predefined import (
@@ -25,6 +25,8 @@ from .driven_controls.predefined import (
     new_corpse_in_bb1_control,
     new_corpse_in_scrofulous_control,
     new_corpse_in_sk1_control,
+    new_drag_control,
+    new_gaussian_control,
     new_modulated_gaussian_control,
     new_primitive_control,
     new_scrofulous_control,
@@ -57,7 +59,9 @@ __all__ = [
     "new_corpse_in_bb1_control",
     "new_corpse_in_scrofulous_control",
     "new_corpse_in_sk1_control",
+    "new_gaussian_control",
     "new_modulated_gaussian_control",
+    "new_drag_control",
     "new_primitive_control",
     "new_scrofulous_control",
     "new_sk1_control",
